@@ -100,7 +100,7 @@
  * along with userv-utils; if not, write to the Free Software
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: service.c,v 1.13 2000/09/18 00:31:11 ian Exp $
+ * $Id: service.c,v 1.14 2000/12/10 22:00:21 ian Exp $
  */
 
 #include <stdio.h>
@@ -329,7 +329,7 @@ static void eat_prefixmask(const char **argp, const char *what,
   sprintf(whatbuf,"%s length",what);
   len= eat_number(argp,whatbuf, 0,32, endchars,endchar_r);
 
-  mask= (~0UL << (32-len));
+  mask= len ? (~0UL << (32-len)) : 0UL;
   if (prefix & ~mask) badusage("%s prefix %08lx not fully contained in mask %08lx",
 			       what,prefix,mask);
   *prefix_r= prefix;
